%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

% Creating Infrastructure Inventory
% For EPA Grid Reliability II
% Alisa White, 4.23.18

addpath(genpath('L:\01 Data\src'));

%Note: the electricity demand by state - for hindcast and projections - 
%were provided by the EPA. The data are discussed in this publication: 

%McFarland, J., Y. Zhou, L. Clarke, P. Sullivan, J. Colman, W. Jaglom, 
%M. Colley, P. Patel, J. Eom, S. Kim, G. Kyle, P. Schultz, B Venkatesh,
%J. Haydel, C. Mack, and J. Creason, 2015: Impacts of rising air 
%temperatures and emissions mitigation on electricity demand and supply in
%the United States: a multi-model comparison. Climatic Change, 
%doi: 10.1007/s10584-015-1380-8.

%% Step 1.  PULL DATA:  State-Level Demand from 2006-2015 data from EIA Form 861

%% Step 1a.  Create Hindcast

%Loads electricity demand by state
[numbers,TEXT,~]=xlsread([home.data '\Data Files\Demand Projection\CIRA2_GCAM_electricity_demand_by_state_20180320_AEW.xlsx'],'Interpolation08_15','B2:P1079');
data=numbers;
text=TEXT;
clear numbers TEXT

ConstTempIndices = strcmp(text(:,3), 'rcpno');

hindcast = nan(num.yearsHind, num.states, num.rcps, num.policy, num.models);
for yr = 1:num.yearsHind
    temp = squeeze(data(:, yr+1));
    %the first five models
    hindcast(yr,:,:,:,1:5) = reshape(temp(~ConstTempIndices), num.states, num.rcps, num.policy, num.models-2); 
    %CanESM as a proxy for GFDL (this was not used in manuscript
    hindcast(yr,:,:,:,6) = hindcast(yr,:,:,:,1); 
    %Constant Temperature (same for both rcps)
    hindcast(yr,:,1,:,7) = reshape(temp(ConstTempIndices), num.states, num.policy);
    hindcast(yr,:,2,:,7) = reshape(temp(ConstTempIndices), num.states, num.policy);
end

%reorder the states
[~, order] = sort(data(1:num.states,1));
hindcast = hindcast(:,order,:,:,:);

%permute to match desired order:  STATE, YEAR, POLICY, MODEL, RCP
hindcast = permute(hindcast, [2, 1, 4, 5, 3]);

%% Step 1b.  Create Forecast Matrix

%Loads forecasted electricity demand by state
clear data text 
[numbers,TEXT,~]=xlsread([home.data '\Data Files\Demand Projection\CIRA2_GCAM_electricity_demand_by_state_20180320_AEW.xlsx'],'Interpolation15_99','B2:CN1079');
data=numbers;
text=TEXT;
clear numbers TEXT 

ConstTempIndices = strcmp(text(:,3), 'rcpno');

forecast = nan(num.yearsFore, num.states, num.rcps, num.policy, num.models);
for yr = 1:num.yearsFore
    temp = squeeze(data(:, yr+1));
    %the first five models
    forecast(yr,:,:,:,1:5) = reshape(temp(~ConstTempIndices), num.states, num.rcps, num.policy, num.models-2); 
    %CanESM as a proxy for GFDL
    forecast(yr,:,:,:,6) = forecast(yr,:,:,:,1); 
    %Constant Temperature (same for both rcps)
    forecast(yr,:,1,:,7) = reshape(temp(ConstTempIndices), num.states, num.policy);
    forecast(yr,:,2,:,7) = reshape(temp(ConstTempIndices), num.states, num.policy);
end

%reorder the states
[~, order] = sort(data(1:num.states,1));
forecast = forecast(:,order,:,:,:);

%permute to match desired order:  STATE, YEAR, POLICY, MODEL, RCP
forecast = permute(forecast, [2, 1, 4, 5, 3]);

%% Step 1c. QC graphs to check the demand trend over time
timeSeries =cat(2, hindcast, forecast);

track = 1;
for rcp = 1:num.rcps
    for policy = 1:num.policy
        temp = squeeze(nansum(timeSeries(:,:,policy, :, rcp), 1));
        subplot(2,2,track)
        plot(temp)
        if rcp == 1; title(names.policy{policy}); end
        if policy == 1; ylabel(names.rcps{rcp}); end
        track = track + 1;
    end
end

figure
rcp = 2;
policy = 2;
plot(squeeze(nansum(timeSeries(:,:,policy, :, rcp), 1)), 'LineWidth', 1.5);
title([names.policy{policy} ' ' names.rcps{rcp}]);
legend(names.models, 'Location', 'southeast');

clear timeSeries

%% STEP 2: Create Delta Demand Matrices

%% Step 2a.  Calculate Deviations from 2015 baseline year
%Ratio of a given year to 2015

%For hindcast
hinddev = nan(num.states, num.yearsHind-1, num.policy, num.models, num.rcps);
for year = 1:num.yearsHind - 1
    hinddev(:,year,:,:,:) = hindcast(:,year,:,:,:) ./ hindcast(:,num.yearsHind,:,:,:);
end

%For forecast
foredev = nan(num.states,num.yearsFore-1,num.policy,num.models,num.rcps);
for year = 1:num.yearsFore - 1
    foredev(:,year,:,:,:) = forecast(:,year+1,:,:,:) ./ forecast(:,1,:,:,:);
end

%% Step 2b. QC 

look = squeeze(nanmean(hinddev(:,:,2,:,2),1));
look2 = squeeze(nanmean(foredev(:,:,2,:,2),1));

clear look look2

min(foredev(:)); % min is 0.943
sum(foredev(:)<1)/numel(foredev)*100; % 4% are less than 1
xxPerc = (bsxfun(@rdivide,forecast,forecast(:,:,:,7,:))-1)*100;
min(xxPerc(:)); % ~8.23% 

% Test ratio of deltas to constant temp for New York State
test=squeeze(bsxfun(@rdivide,foredev(31,:,2,:,2),foredev(31,:,2,7,2)));
%Looks good

%Graphs of deviations from baseline
subplot(2,1,1)
hist(reshape(hinddev, [],1), 50);
title('hind deviations');
subplot(2,1,2)
hist(reshape(foredev, [],1), 50);
title('fore deviations');

%% STEP 3: Apply Delta Demand Matrix to project infrastrucure elements

%% Step 3a.  Project Out the Infrastructure Inventory

%Load State-Level Infrastructure Data
clear data
%This state level infrastructure data was compiled in part using data from
%S&P Global Platts 2017 UDI Directory of Electric Power Producers. Please
%contact S&P Global for more information about purchasing this database

infra = xlsread([home.data '\Data Files\InfrastructureInventoryFull.xlsx'],'State','B2:G50');

%Forecast at state level
Invforecast = nan(num.states, num.infra, num.yearsFore-1, num.policy, num.models, num.rcps);
for inf = 1:num.infra
    for state=1:num.states        
        Invbase = infra(state,inf+1);
        Invforecast(state, inf,:,:,:,:) = Invbase * foredev(state, :,:,:,:);      
    end
end

%Backcast at state level
Invbackcast=nan(num.states,num.infra,num.yearsHind-1,num.policy,num.models,num.rcps);
for inf=1:num.infra
    for state=1:num.states      
        Invbase=infra(state,inf+1);
        Invbackcast(state, inf, :,:,:,:) = Invbase * hinddev(state, :,:,:,:);
    end
end

%% Step 3b.  Break down to County Level

%Break each down to the county level
clear data

%This county level infrastructure data was compiled in part using data from
%S&P Global Platts 2017 UDI Directory of Electric Power Producers. Please
%contact S&P Global for more information about purchasing this database
percents=xlsread([home.data '\Data Files\InfrastructureInventoryFull.xlsx'],'percents','A2:G3110');

% QC percents to make sure no loss when converting to county level
xxstate = percents(:,2);
xxshouldBeOnes = nan(num.states,num.infra);
for s = 1:num.states
 xxshouldBeOnes(s,:) = sum(percents(xxstate==names.states(s),3:end),1);
end
% all are ones!

ForecastFinal= nan(num.counties,num.infra,num.yearsFore-1,num.policy,num.models,num.rcps);
HindcastFinal = nan(num.counties,num.infra,num.yearsHind-1,num.policy,num.models,num.rcps);
for county=1:num.counties
    %Find percent of state-level infrastructure in given county
    index1 = percents(:,1)==names.counties(county);
    perccount = percents(index1,:);
    statecode = perccount(:,2);
    [row,col]=find(states==statecode);
    for infra=1:num.infra
        ForecastFinal(county,infra,:,:,:,:)=Invforecast(row,infra,:,:,:,:).*perccount(infra+2);
        HindcastFinal(county,infra,:,:,:,:)=Invbackcast(row,infra,:,:,:,:).*perccount(infra+2);
    end
end


% QC Forecast Final - checks on if it matches state level deviations
xxPercChange = (bsxfun(@rdivide,ForecastFinal,ForecastFinal(:,:,1,:,:,:))-1)*100; 
min(xxPercChange(:)); % Good ~5.5% -> matches the 0.945 in "foredev"
xxPercChange = (bsxfun(@rdivide,ForecastFinal,ForecastFinal(:,:,:,:,7,:))-1)*100; 
min(xxPercChange(:)); % Good ~8.1% less than constant temperature
sum(isnan(ForecastFinal(:)))/numel(ForecastFinal); % good


clear Invforecast Invbackcast foredev forecast hinddev hindcast
%% Step 4. Present Day (2015) Infra Matrix

%This county level infrastructure data was compiled in part using data from
%S&P Global Platts 2017 UDI Directory of Electric Power Producers. Please
%contact S&P Global for more information about purchasing this database
presentday=xlsread([home.data '\Data Files\InfrastructureInventoryFull.xlsx'],'Full','C2:G3110');

%Concatenate the hindcast, present day (2015), and forecast
Delta = bsxfun(@minus, ForecastFinal, presentday);
PresentDay = repmat(presentday, 1, 1, 1, 2, 7, 2);
FinalMat=cat(3,HindcastFinal,PresentDay,ForecastFinal);

data=FinalMat;
clear key;
key.dims = {'counties', 'infrastructure', 'years','policy','models','rcps'};
key.counties = names.counties;
key.infrastructure = names.infra;
key.years = 2006:2100;
key.policy = names.policy;
key.models = names.models;
key.rcps = names.rcps;
key.units = {'units'};

%Save the full infrastructure
save([home.outputs '\MAT files\Infrastructure_Inventory'], 'data', 'key');
clear data


%% STEP 5.  Post Processing: Summary Stats

%What is change in infra from 2015 to 2100 for each gcm and type of
%infrastructure?
Change=permute(squeeze(nansum(Delta(:,:,85,:,:,1),1)),[3 1 2]);

for rcp=1:num.rcps
    xlsTable([home.outputs '\Data Files\Infra_Delta'],Delta(:,:,rcp),...
        names.rcps{rcp},names.models,names.infra, {'Elements'}, {'Number'});
end

Total=permute(squeeze(nansum(FinalMat(:,:,85,:,:,1),1)),[3 1 2]);
for rcp=1:num.rcps
    xlsTable([home.outputs '\Data Files\Total_Infra_2100'],Total(:,:,rcp),...
        names.rcps{rcp},names.models,names.infra, {'Elements'}, {'Number'});
end


