
%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%
%*********************************
% Estimates changes in lifespan and strength of timber poles
% 
% Based on Wang and Wang (2012)
% Precipitation and temperature impact the decay rate of timber poles via
% fungal attacks on the outer edge of the pole base
%*********************************
% 
% [lifespan, strength] = TandP_WoodPoleLifespan(temp,precip,class) 
% 
% INPUT 
%   temp: monthly mean temperature (C) for 1 year where columns are
%           months and rows are locations (days,locs)
%   precip: same as temp but total monthly precip (mm/month)
% 
% OUTPUT
%   lifespan: new estimated lifespan of the pole
%   strength reduction: new strength rating (may not use)
% 
%{
  % test
  class = 2;
  temp0 = repmat(25,3e3,12);
  temp1 = repmat(linspace(0,40,3e3)',1,12);
  precip0 = repmat(200,3e3,12);
  precip1 = repmat(linspace(0,300,3e3)',1,12);
  r0 = TandP_WoodPoleLifespan(temp0,precip0,class);%,rlast,age,treat);
  rT = TandP_WoodPoleLifespan(temp1,precip0,class);%,rlast,age,treat);
  rP = TandP_WoodPoleLifespan(temp0,precip1,class);%,rlast,age,treat);
  r1 = TandP_WoodPoleLifespan(temp1,precip1,class);%,rlast,age,treat);
  subplot(3,1,1)
  plot(temp1,rT,'k.')
  title('Temp Effect')
  xlabel('temperature')
  ylabel('decay rate (mm/year)')
  subplot(3,1,2)
  plot(precip1,rP,'k.')
  title('Precip Effect')
  xlabel('Precip')
  ylabel('decay rate (mm/year)')
  subplot(3,1,3)
  plot(temp1,r1,'k.')
  title('Combined Effect')
  xlabel('Temp')
  ylabel('decay rate (mm/year)')
D = 263;
Strength = (D - rT*32).^3 ./ (D^3);
figure
plot(temp1,Strength)
  %}
% 

function [r,S] = ...[polesLost,rnow,poleCountNew,Strength]
  TandP_WoodPoleLifespan(temp,precip,class)%,D,rlast,poleCount,treatment,minStrFrac) 

maxLife = 50;
% minStrFrac = 0.80;

Nlocs = size(temp,1);
Nage = maxLife;

% age = repmat(1:maxLife,Nlocs,1); % evaluate for all ages

%-- durability class factor kw
switch class
  case 1
    kw = 0.23;
  case 2
    kw = 0.48;
  otherwise
    kw = 0.76;
end

%-- PRECIP effect (Fr)
Fr = nan(Nlocs,1);
Pmean = sum(precip,2); % annual precip (mm/year)
Ndm = sum(precip <= 5,2);% number of dry months
% if more than 6 dry months, no precip effect
ind0 = Ndm>6 | Pmean<250;
Fr(ind0) = 0; 
% otherwise, there is a precip effect
Fr(~ind0) = 10 * (1 - exp(-0.001.*(Pmean(~ind0)-250))) .* (1-Ndm(~ind0)/6);
Fr(Fr<0) = 0;

%-- TEMP effect (Gt)
Gt = nan(Nlocs,1);
Tmean = mean(temp,2);
% no effect if Tmean is less than 5 C
Gt(Tmean<5) = 0;
% midrange temperature effect [5 to 20]
indM = Tmean < 20 & Tmean >= 5;
Gt(indM) = -1 + .2*Tmean(indM);
% high temp range
indH = Tmean>=20;
Gt(indH) = -25 + 1.4 * Tmean(indH);

%-- fungal decay rate
r = kw .* Fr.^.3 .* Gt.^.2;
% r = repmat(kw .* Fr .* Gt,1,Nage); % mm/year

D = 263; % Diameter for Class 5 pole
life = 32; %32 years (Morrel 2005)
S = (D - r*life).^3 ./ (D^3); % strength fraction after end of life 

%{

%-- time lag
tlag = 3*r.^-.4;
d0 = 5; %mm (Wang et al. 2008)
td0 = tlag + d0./r;
c = d0./td0.^2;
depth = nan(Nlocs,Nage);
ia = age<=td0;
depth(ia) = c(ia).*age(ia).^2;
depth(~ia) = (age(~ia)-tlag(~ia)).*r(~ia);
rlag = depth ./ age; % convert back to a rate mm/year

rnow = rlast + (rlag .* treatment); % total mm so far (assume treatment reduces rate linearly)

%-- Strength Reduction
Strength = (pi()/32) .* (D - rnow).^3;
Strength(Strength<0) = 0;

%-- poles lost !! ALL BELOW Needs to be fixed!!!!!
minStr = minStrFrac * (pi()/32*D^3);
deadPolesStr = Strength <= minStr; % dead poles from strength probs

% total dead poles
deadPoles = (nansum(deadPolesStr.*poleCount,2) + poleCount(:,end));
poleCount(deadPolesStr) = 0;
poleCountNew = [deadPoles poleCount(:,1:end-1)];

polesLost = deadPoles ./ sum(poleCount,2);

%}

% update
% rnow(deadPolesStr) = NaN;


