%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

%*********************************
% Estimates reduction in large(power) transformer peak load capacity given
% a timeseries of temperature. 
% Chas Fant June 2018
% 
% Based on Li et al. (2005)
% Temperatures above 30 reduce capacity by 0.7% for each degree above 30
% 
%*********************************
% 
% capfrac = Temp_PowerTransCap(temp,tran) 
% 
% INPUT 
%   temp: matrix of mean daily temperature (C) for 1 year where columns are
%           days and rows are locations (days,locs)
%   tran: vector of daily temperature range (C) for 1 year, same format as
%           temp
% 
% OUTPUT
%   capfrac: annual maximum capacity reduction as a fraction, where
%             New_cap = (original_cap) * (1-capfrac)
%   temph: hourly temperature  
% 
%{
  % test
  temp = rand(3e3,365)*40;
  tran = rand(size(temp))*10;
  [capfrac,temph] = Temp_PowerTransCap(temp,tran);
  plot(max(temph,[],2),capfrac,'k.')
  %}
% 
%-- next steps/notes:
% a.) Use mean $ / new transformer capacity (MW) to estimate costs (make sure to
% compare to previous years where capacity was built to make sure it was not built in a previous year)
% b.) Update number of large transformers per county to reflect new transmission
% c.) Record new transformer capacity so we do not double count capacity already built
% d.) Will need to keep track of design-based capacity vs temp-based capacity
% 
% 
% 
function capfrac = Temp_PowerTransCap(tmax)
  
%   num.loc = size(temp,1);
%   num.day = size(temp,2);
% 
%   % construct hourly temperature
%   temph = nan(num.loc,num.day*24);
%   for loc = 1:size(temp,1)
%     temph(loc,:) = reshape(bsxfun(@times,repmat(tran(loc,:),24,1),sin(pi*((1:24)-9.5)/12)'),1,[])+...
%       reshape(repmat(temp(loc,:),24,1),1,[]);
%   end

  % degrees above 30
  hightemp = tmax - 30;
  hightemp(hightemp<0)=0;

  % daily capfrac 
  capfracVec = hightemp * .007;

  % peak capfrac
  capfrac = max(capfracVec,[],2);

end




