%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

function I = Temp_TransLine_Ampacity(Tamb,Voltage,Tcond,type)

%% parameters

em = 0.7;% emissivity
sigma = 5.670367e-8;% Stefan Boltzmann constant = 5.670367?10?8 W/(m^2*K^4).
rad = 1000;% assumed incident solar radiation (W/m^2)
as = 0.9;% absorptivity of surface (unitless)
V = 0.61; % assumed wind speed (m/s)

%% Tables 

% Table of air properties 
%   Incropera F. P., DeWitt D. P., Bergman T. L., Lavine A. S. (2002). 
%   Fundamentals of heat and mass transfer. New York: J. Wiley.
% temperature [K]
AirTab.T = [200;250;300;350;400;450;500;550;600];
% Viscosity [(m2/s) e-6]
AirTab.v = [7.59;11.44;15.89;20.92;26.41;32.39;38.79;45.57;52.69]*1e-6;
% Thermal Conductivity [(W/m*K) e -3]
AirTab.k = [18.1;22.3;26.3;30;33.8;37.3;40.7;43.9;46.9]*1e-3;
% Prandtl Number (-)
AirTab.Pr = [0.737;0.720;0.707;0.700;0.690;0.686;0.684;0.683;0.685];

% cable characteristics
volts = [69 115 230 345 500];
ind = findClosestInd(volts,Voltage); % find closests voltage
vol = volts(ind);
switch vol % nominal volage (kV)
  case 500 % 3 x 954 kcm ACSR Cardinal
    D = 3.04; % (cm)
    R25 = 0.061; % (Ohms/km)
    R50 = 0.067;
    R75 = 0.073;
  case 345 % 2 x 954 kcm ACSR Cardinal
    D = 3.04;
    R25 = 0.061;
    R50 = 0.067;
    R75 = 0.073;
  case 230 % 1 x 1351 kcm ACSR Martin
    D = 3.62;
    R25 = 0.044;
    R50 = 0.048;
    R75 = 0.052;
  case 115 % 1 x 795 kcm ACSR Condor
    D = 2.77;
    R25 = 0.073;
    R50 = 0.080;
    R75 = 0.087;
  case 69 % 1 x 336 kcm ACSR Linnet
    D = 1.83;
    R25 = 0.170;
    R50 = 0.186;
    R75 = 0.203;
  case 68 % distribution is anything below 69
    D = 0.09;
    R25 = 0.78;
    R50 = 0.84;
    R75 = 0.9;
end
D = D/1e5; 

switch type
  case 'ACSS'
    xx = 1.26;
    R25 = R25 / xx;
    R50 = R50 / xx;
    R75 = R75 / xx;
  case 'ACCC'
    xx = 1.37;
    R25 = R25 / xx;
    R50 = R50 / xx;
    R75 = R75 / xx;
end

%% temperature dependant parameters

Tamb = Tamb + 273.15;
Tcond = Tcond + 273.15; 

Tf = (Tcond + Tamb)./2;% film temperature
% Tf = Tamb;
Pr = interp1(AirTab.T,AirTab.Pr,Tamb); % Prandtl number (table lookup)
v = interp1(AirTab.T,AirTab.v,Tamb); % viscosity (table lookup)
k = interp1(AirTab.T,AirTab.k,Tf); % Thermal Conductivity of air (table lookup)

% average heat transfer coefficient 
Re = V .* D ./ v; % eq 13
c = (Re ./ 282000) .^ (5/8); % eq 12
b = (1 + (0.4./Pr).^(2/3)).^(1/4); % eq 11
a = 0.62 .* Re.^(0.5) .* Pr.^(1/3); % eq 10
Nu = 0.3 + a./b .* (1 + c).^(4/5); %eq 9
hbar = Nu .* k ./ D; % eq 7

%% The Heat!

% heat loss due to convection
qc = pi() .* hbar .* D .* (Tcond-Tamb);

% heat gain from solar radiation striking the top half of the surface of
% the conductor
qs = pi() * em * sigma * D * (Tcond^4 - Tamb.^4);

% heat loss due to radiation
qr = rad * D * as;

% resistance of the conductor at a given conductor temperature (Eq 4)
if (Tcond - 273.15) < 50
  R = (R25 + (R25-R50)/-25 * (Tcond - 25)) ./ 1e3; % ohms / m
else
  R = (R50 + (R50-R75)/-25 * (Tcond - 50)) ./ 1e3;
end

%% ampacity
I = sqrt( (qc+qr-qs) ./ R); % Eq 5

end